# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterDigestNormalizedYearlyResponseResults(Model):
    """MeterDigestNormalizedYearlyResponseResults.

    :param year: year
    :type year: str
    :param native_use: Native use
    :type native_use: float
    :param native_demand: Native demand
    :type native_demand: float
    :param common_use: Common use
    :type common_use: float
    """

    _attribute_map = {
        'year': {'key': 'year', 'type': 'str'},
        'native_use': {'key': 'nativeUse', 'type': 'float'},
        'native_demand': {'key': 'nativeDemand', 'type': 'float'},
        'common_use': {'key': 'commonUse', 'type': 'float'},
    }

    def __init__(self, year=None, native_use=None, native_demand=None, common_use=None):
        super(MeterDigestNormalizedYearlyResponseResults, self).__init__()
        self.year = year
        self.native_use = native_use
        self.native_demand = native_demand
        self.common_use = common_use
